@@ -58,7 +58,7 @@ def password_entry():
     return getpass.getpass(log.bold("Please enter the root/superuser password: "))
 
 def password_user_entry():
-    return getpass.getpass(log.bold("Please enter the user (%s)'s password: " % os.getenv('USER')))
+    return getpass.getpass(log.bold("Please enter the sudoer (%s)'s password: " % os.getenv('USER')))
 
 
 def option_question_callback(opt, desc, default='y'):
@@ -201,6 +201,9 @@ def start(language, auto=True, test_depends=False,
         if not ok:
             sys.exit(0)
 
+        if distro_alternate_version:
+            core.distro_version = distro_alternate_version
+
         core.distro_changed()
 
         if not distro_ok:
@@ -653,7 +656,13 @@ def start(language, auto=True, test_depends=False,
             #
             # HPLIP REMOVE
             #
-            if core.hplip_present and core.selected_component == 'hplip' and core.distro_version_supported:
+            num_req_missing = 0
+            core.check_dependencies()
+            for depend, desc, opt in core.missing_required_dependencies():
+                log.error("A required dependency '%s (%s)' is still missing." % (depend, desc))
+                num_req_missing += 1
+
+            if num_req_missing == 0 and core.hplip_present and core.selected_component == 'hplip' and core.distro_version_supported:
                 path = utils.which('hp-uninstall')
                 ok, choice = tui.enter_choice("HPLIP-%s exists, this may conflict with the new one being installed.\nDo you want to ('i'= Remove and Install, 'o'= Overwrite*, 'q'= Quit)?	:"%(prev_hplip_version),['i','o','q'],'o')
                 if not ok or choice=='q':
@@ -757,6 +766,12 @@ def start(language, auto=True, test_depends=False,
 
         tui.title("POST-BUILD COMMANDS")
         core.run_post_build(progress_callback, distro_alternate_version)
+        try:
+            from prnt import cups
+            #This call is just to update the cups PPD cache file@ /var/cache/cups/ppds.dat. If this is not called, hp-setup picks incorrect ppd 1st time for some printers. 
+            cups.getSystemPPDs()
+        except ImportError:
+            log.error("Failed to Import Cups")
 
         #
         # OPEN MDNS MULTICAST PORT
