@@ -198,7 +198,7 @@ Keep-Alive: 20\r\nProxy-Connection: keep-alive\r\nCookie: AccessCounter=new\r\n0
 <ToneMap>\
 <Gamma>0</Gamma>\
 <Brightness>1000</Brightness>\
-<Contrast>1000</Contrast>\
+<Contrast>%d</Contrast>\
 <Highlite>0</Highlite>\
 <Shadow>0</Shadow></ToneMap>\
 <ContentType>Photo</ContentType></ScanSettings>" 
@@ -690,17 +690,26 @@ int bb_open(struct ledm_session *ps)
   ps->adf_tlyRange.max = SANE_FIX(pbb->elements.config.adf.maximum_size.height/11.811023);
   ps->adf_bryRange.max = ps->adf_tlyRange.max;
 
-  i = pbb->elements.config.platen.platen_resolution_list[0] + 1;
-  while(i--)
+  if (pbb->elements.config.platen.flatbed_supported)
   {
-  _DBG("bb_open platen_resolution_list = %d\n",  pbb->elements.config.platen.platen_resolution_list[i]);
-    ps->platen_resolutionList[i] = pbb->elements.config.platen.platen_resolution_list[i];
-    ps->resolutionList[i] = pbb->elements.config.platen.platen_resolution_list[i];
+      i = pbb->elements.config.platen.platen_resolution_list[0] + 1;
+      while(i--)
+      {
+          _DBG("bb_open platen_resolution_list = %d\n",  pbb->elements.config.platen.platen_resolution_list[i]);
+          ps->platen_resolutionList[i] = pbb->elements.config.platen.platen_resolution_list[i];
+          ps->resolutionList[i] = pbb->elements.config.platen.platen_resolution_list[i];
+      }
+  }
+  if (pbb->elements.config.adf.supported)
+  {
+     i = pbb->elements.config.adf.adf_resolution_list[0] + 1;
+     while(i--)
+     {
+         _DBG("bb_open adf_resolution_list = %d\n", pbb->elements.config.adf.adf_resolution_list[i]);
+         ps->adf_resolutionList[i] = pbb->elements.config.adf.adf_resolution_list[i]; 
+         ps->resolutionList[i] = pbb->elements.config.adf.adf_resolution_list[i];
+     }
   }
-
-  i = pbb->elements.config.adf.adf_resolution_list[0] + 1;
-  while(i--) ps->adf_resolutionList[i] = pbb->elements.config.adf.adf_resolution_list[i]; 
-
   stat = 0;
 
 bugout:
@@ -709,9 +718,11 @@ bugout:
 
 int bb_close(struct ledm_session *ps)
 {
-  _DBG("bb_close()\n");
-  free(ps->bb_session);
-  ps->bb_session = NULL;
+  if (ps->bb_session)
+  {
+      free(ps->bb_session);
+      ps->bb_session = NULL;
+  }
   return 0;
 } 
 
@@ -782,6 +793,17 @@ int bb_get_parameters(struct ledm_session *ps, SANE_Parameters *pp, int option)
 return 0;
 }
 
+/***
+* Function: bb_is_paper_in_adf()
+* Arguments: 
+*    1) struct ledm_session *ps (IN)
+*
+* Return Value: (type: Int)
+*    0  = no paper in adf,
+*    1  = paper in adf,
+*    -1 = error
+*/
+
 int bb_is_paper_in_adf(struct ledm_session *ps) /* 0 = no paper in adf, 1 = paper in adf, -1 = error */
 {
   char buf[1024];
@@ -799,9 +821,16 @@ int bb_is_paper_in_adf(struct ledm_session *ps) /* 0 = no paper in adf, 1 = pape
 
   http_close(pbb->http_handle);   /* error, close http connection */
   pbb->http_handle = 0;
-  _DBG("bb_is_paper_in_adf .job_id=%d buf=%s\n", ps->job_id, buf);
+  _DBG("bb_is_paper_in_adf .job_id=%d page_id=%d buf=%s \n", ps->job_id, ps->page_id, buf );
   if(strstr(buf, ADF_LOADED)) return 1;
-  if(strstr(buf, ADF_EMPTY)) return 0;
+  if(strstr(buf, ADF_EMPTY))
+  {
+     if (strstr(buf, SCANNER_BUSY_WITH_SCAN_JOB)) return 1;
+     if (ps->currentInputSource ==IS_ADF_DUPLEX && ps->page_id % 2 == 1)
+        return 1;
+     else  
+        return 0;
+  }
   else return -1;
 }
 
@@ -858,7 +887,8 @@ SANE_Status bb_start_scan(struct ledm_session *ps)
     	((! strcmp(ce_element[ps->currentScanMode], "Color8")) || (! strcmp(ce_element[ps->currentScanMode], "Gray8"))) ? 8: 8,//<BitDepth>
     	ps->currentInputSource == IS_PLATEN ? is_element[1] : is_element[2],//<InputSource>
     	ps->currentInputSource == IS_PLATEN ? is_element[1] : is_element[2],//<InputSourceType>
-    	ps->currentInputSource != IS_ADF_DUPLEX ? "" : "<AdfOptions><AdfOption>Duplex</AdfOption></AdfOptions>");
+    	ps->currentInputSource != IS_ADF_DUPLEX ? "" : "<AdfOptions><AdfOption>Duplex</AdfOption></AdfOptions>",
+        (int)ps->currentContrast);//<Contrast>
 
     len = len + strlen(ZERO_FOOTER);
 
