@@ -36,6 +36,7 @@ from prnt import cups
 from base.codes import *
 from ui_utils import *
 import hpmudext
+from installer.core_install import *
 
 # Qt
 from PyQt4.QtCore import *
@@ -166,8 +167,7 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
         log.debug("Initializing toolbox UI (Qt4)...")
         log.debug("HPLIP Version: %s" % prop.installed_version)
 
-        self.setupUi(self)
-
+        
         self.toolbox_version = toolbox_version
         self.initial_device_uri = initial_device_uri
         self.device_vars = {}
@@ -177,13 +177,23 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
         self.updating = False
         self.init_failed = False
         self.service = None
+        self.Is_autoInstaller_distro = False		# True-->tier1(supports auto installation).   		False--> tier2(manual installation)
 
+        # Distro insformation
+        core =  CoreInstall(MODE_CHECK)
+#        core.init()
+        self.Is_autoInstaller_distro = core.is_auto_installer_support()
         # User settings
         self.user_settings = UserSettings()
         self.user_settings.load()
         self.user_settings.debug()
         self.cur_device_uri = self.user_settings.last_used_device_uri
-
+        installed_version=sys_conf.get('hplip','version')
+        if not utils.Is_HPLIP_older_version( installed_version,  self.user_settings.latest_available_version):
+            self.setupUi(self,"",self.Is_autoInstaller_distro)
+        else:
+            self.setupUi(self, self.user_settings.latest_available_version,self.Is_autoInstaller_distro)
+            
         # Other initialization
         self.initDBus()
         self.initPixmaps()
@@ -258,6 +268,9 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
 
         self.PreferencesAction.setIcon(QIcon(load_pixmap('settings', '16x16')))
         self.connect(self.PreferencesAction, SIGNAL("triggered()"), self.PreferencesAction_activated)
+        
+        self.DiagnoseQueueAction.setIcon(QIcon(load_pixmap('warning', '16x16')))
+        self.connect(self.DiagnoseQueueAction, SIGNAL("triggered()"), self.DiagnoseQueue_activated)
 
         self.ContentsAction.setIcon(QIcon(load_pixmap("help", "16x16")))
         self.connect(self.ContentsAction, SIGNAL("triggered()"), self.helpContents)
@@ -278,6 +291,7 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
         self.initPrintSettingsTab()
         self.initPrintControlTab()
 
+
         self.connect(self.Tabs,SIGNAL("currentChanged(int)"),self.Tabs_currentChanged)
 
         # Resize the splitter so that the device list starts as a single column
@@ -295,6 +309,7 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
                           2: self.updateSuppliesTab,
                           3: self.updatePrintSettingsTab,
                           4: self.updatePrintControlTab,
+                          5:self.updateHPLIPupgrade,
                         }
 
         # docs
@@ -394,7 +409,7 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
 
             elif event.event_code == EVENT_SYSTEMTRAY_EXIT:
                 log.debug("EVENT_SYSTEMTRAY_EXIT")
-                log.error("HPLIP Status Service was closed. HPLIP Device Manager will now exit.")
+                log.warn("HPLIP Status Service was closed. HPLIP Device Manager will now exit.")
                 self.close()
 
             elif event.event_code == EVENT_RAISE_DEVICE_MANAGER:
@@ -643,8 +658,9 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
                     device_list[d] = dev
 
                 log.debug("Removals (2): %s" % ','.join(removals))
-
+                removed_device=None
                 for d in removals:
+                    removed_device = d
                     index = self.DeviceList.count()-1
                     item = self.DeviceList.item(index)
                     log.debug("removing: %s" % d)
@@ -666,7 +682,10 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
 
                 self.DeviceList.updateGeometry()
                 qApp.processEvents()
-
+                # sending Event to remove this device from hp-systray
+                if removed_device:
+                    utils.sendEvent(EVENT_CUPS_QUEUES_CHANGED,removed_device, "")
+                
                 if len(device_list):
                     for tab in self.TabIndex:
                         self.Tabs.setTabEnabled(tab, True)
@@ -711,6 +730,7 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
                     self.cur_device = None
                     self.DeviceRefreshAction.setEnabled(False)
                     self.RemoveDeviceAction.setEnabled(False)
+                    self.DiagnoseQueueAction.setEnabled(False)
                     self.updating = False
                     self.statusBar().showMessage(self.__tr("Press F6 to refresh."))
 
@@ -1074,7 +1094,7 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
                     self.__tr("Print a test page to test the setup of your printer."),
                     lambda : PrintTestPageDialog(self, self.cur_printer)),
 
-                    (lambda : True,
+                     (lambda : True,
                     self.__tr("View Printer and Device Information"),
                     "cups",
                     self.__tr("View information about the device and all its CUPS queues."),
@@ -1143,7 +1163,7 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
                     "plugin",
                     x,
                     lambda : PluginInstall(self, d.plugin, plugin_installed)),
-
+                    
                     # EWS
 
                     (lambda : printer and d.embedded_server_type > EWS_NONE and bus == 'net',
@@ -1446,26 +1466,21 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
                 self.cur_device.status_type != STATUS_TYPE_NONE and \
                 self.cur_device.device_state != DEVICE_STATE_NOT_FOUND:
 
-                try:
-                    self.cur_device.sorted_supplies
-                except AttributeError:
-                    self.cur_device.sorted_supplies = []
+                self.cur_device.sorted_supplies = []
+                a = 1
+                while True:
+                    try:
+                        agent_type = int(self.cur_device.dq['agent%d-type' % a])
+                        agent_kind = int(self.cur_device.dq['agent%d-kind' % a])
+                        agent_sku = self.cur_device.dq['agent%d-sku' % a]
+                    except KeyError:
+                        break
+                    else:
+                        self.cur_device.sorted_supplies.append((a, agent_kind, agent_type, agent_sku))
 
-                if not self.cur_device.sorted_supplies:
-                    a = 1
-                    while True:
-                        try:
-                            agent_type = int(self.cur_device.dq['agent%d-type' % a])
-                            agent_kind = int(self.cur_device.dq['agent%d-kind' % a])
-                            agent_sku = self.cur_device.dq['agent%d-sku' % a]
-                        except KeyError:
-                            break
-                        else:
-                            self.cur_device.sorted_supplies.append((a, agent_kind, agent_type, agent_sku))
+                    a += 1
 
-                        a += 1
-
-                    self.cur_device.sorted_supplies.sort(lambda x, y: cmp(x[1], y[1]) or cmp(x[3], y[3]))
+                self.cur_device.sorted_supplies.sort(lambda x, y: cmp(x[1], y[1]) or cmp(x[3], y[3]))
 
                 self.SuppliesTable.setRowCount(len(self.cur_device.sorted_supplies))
                 self.SuppliesTable.setColumnCount(len(self.supplies_headers))
@@ -1739,6 +1754,34 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
         # TODO: Check queues at startup and send events if stopped or rejecting
 
 
+    def initUpgradeTab(self):
+        self.connect(self.InstallLatestButton, SIGNAL("clicked()"), self.InstallLatestButton_clicked)
+        self.InstallLatestButton_lock = False
+        
+       
+    def InstallLatestButton_clicked(self):
+        if self.InstallLatestButton_lock is True:
+            return
+        if self.Is_autoInstaller_distro:
+            self.InstallLatestButton.setEnabled(False)
+            terminal_cmd = utils.get_terminal()
+            if terminal_cmd is not None and utils.which("hp-upgrade"):
+                cmd = terminal_cmd + " 'hp-upgrade -w'"
+                log.debug("cmd = %s " %cmd)
+                os.system(cmd)
+            else:
+                log.error("Failed to run hp-upgrade command from terminal =%s "%terminal_cmd)
+            self.InstallLatestButton.setEnabled(True)
+        else:
+            self.InstallLatestButton_lock = True
+            utils.openURL("http://hplipopensource.com/hplip-web/install/manual/index.html")
+            QTimer.singleShot(1000, self.InstallLatestButton_unlock)
+
+
+    def InstallLatestButton_unlock(self):
+        self.InstallLatestButton_lock = False
+
+
     def CancelJobButton_clicked(self):
         item = self.JobTable.currentItem()
 
@@ -1752,7 +1795,12 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
     def RefreshButton_clicked(self):
         self.updatePrintControlTab()
 
+    def  updateHPLIPupgrade(self):
+        self.initUpgradeTab()
 
+        
+        
+        
     def updatePrintControlTab(self):
         if self.cur_device.device_type == DEVICE_TYPE_PRINTER:
             self.PrintControlPrinterNameLabel.setText(self.__tr("Printer Name:"))
@@ -1898,7 +1946,7 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
                 self.cur_device.sendEvent(e, self.cur_printer)
             else:
                 if os.geteuid!=0 and utils.addgroup()!=[]:
-                    FailureUI(self, self.__tr("<b>Start/Stop printer queue operation fails.</b><p>Please add user to %s group(s)" %utils.list_to_string(utils.addgroup())))
+                    FailureUI(self, self.__tr("<b>Start/Stop printer queue operation fails. Could not connect to CUPS Server</b><p>Is user added to %s group(s)" %utils.list_to_string(utils.addgroup())))
 
         finally:
             endWaitCursor()
@@ -1929,7 +1977,7 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
                 self.cur_device.sendEvent(e, self.cur_printer)
             else:  
                 if os.geteuid!=0 and utils.addgroup()!=[]:
-                    FailureUI(self, self.__tr("<b>Accept/Reject printer queue operation fails.</b><p>Please add user to %s group(s)" %utils.list_to_string(utils.addgroup())))
+                    FailureUI(self, self.__tr("<b>Accept/Reject printer queue operation fails. Could not connect to CUPS Server</b><p>Is user added to %s group(s)" %utils.list_to_string(utils.addgroup())))
 
         finally:
             endWaitCursor()
@@ -1942,7 +1990,7 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
             result = cups.setDefaultPrinter(self.cur_printer.encode('utf8'))
             if not result:
                 if os.geteuid!=0 and utils.addgroup()!=[]:
-                    FailureUI(self, self.__tr("<b>Set printer queue as default operation fails.</b><p>Please add user to %s group(s)" %utils.list_to_string(utils.addgroup())))
+                    FailureUI(self, self.__tr("<b>Set printer queue as default operation fails. Could not connect to CUPS Server</b><p>Is user added to %s group(s)" %utils.list_to_string(utils.addgroup())))
             else:
                 self.updatePrintController()
                 if self.cur_device.device_type == DEVICE_TYPE_PRINTER:
@@ -2060,6 +2108,15 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
         self.rescanDevices()
         self.updatePrinterCombos()
 
+    def DiagnoseQueue_activated(self):
+        if utils.which('hp-diagnose_queues'):
+            cmd= 'hp-diagnose_queues'
+        else:
+            cmd= 'python ./diagnose_queues.py'
+        log.debug(cmd) 
+        ok, output = utils.run(cmd)
+
+
 
     # ***********************************************************************************
     #
